import type { ServiceManager } from '@jupyterlab/services';
import React from 'react';
import { type CollaborationServer } from './BaseNotebook';
import type { INotebookProps } from './Notebook';
import type { NotebookModel } from '@jupyterlab/notebook';
import type { CommandRegistry } from '@lumino/commands';
import './Notebook.css';
export interface ISimpleNotebookProps extends Omit<INotebookProps, 'CellSidebar' | 'cellMetadataPanel' | 'collaborative' | 'kernel' | 'lite' | 'nbgrader' | 'serverless' | 'useRunningKernelId' | 'useRunningKernelIndex' | 'kernelClients' | 'kernelTransfer'> {
    /**
     * Collaboration server providing the document rooms
     */
    collaborationServer: CollaborationServer;
    /**
     * Custom command registry.
     *
     * Note:
     * Providing it allows to command the component from an higher level.
     */
    commands?: CommandRegistry;
    /**
     * Kernel ID to connect to.
     */
    kernelId?: string;
    /**
     * Jupyter service manager.
     */
    serviceManager: ServiceManager.IManager;
    /**
     * Callback on notebook model changed
     */
    onNotebookModelChanged?: (model: NotebookModel | null) => void;
}
/**
 * Simple notebook component without adapter and stores.
 *
 * Notes:
 * - You must provide the appropriate service manager
 * - You can specified the kernel id to use; if it is not defined or empty and startDefaultKernel is true, a new kernel will be started.
 */
export declare function SimpleNotebook(props: React.PropsWithChildren<ISimpleNotebookProps>): JSX.Element;
